@@ -2,10 +2,10 @@
 """Generate Python code from PSP templates.
 
 	This module holds the classes that generate the Python code resulting
-	from the PSP template file.	As the parser encounters PSP elements,
+	from the PSP template file. As the parser encounters PSP elements,
 	it creates a new Generator object for that type of element.
 	Each of these elements is put into a list maintained by the
-	ParseEventHandler object. When it comes	time to output the source code,
+	ParseEventHandler object. When it comes time to output the source code,
 	each generator is called in turn to create its source.
 
 	(c) Copyright by Jay Love, 2000 (mailto:jsliv@jslove.org)
@@ -111,6 +111,8 @@ class ScriptGenerator(GenericGenerator):
 		if self.chars[:1] == ' ' and self.chars[:2] != '  ':
 			self.chars = self.chars.lstrip()
 		lines = PSPUtils.splitLines(PSPUtils.removeQuotes(self.chars))
+		if not lines:
+			return # ignore empty tag
 		# userIndent check
 		if len(lines[-1]) > 0 and lines[-1][-1] == '$':
 			lastline = lines[-1] = lines[-1][:-1]
@@ -319,7 +321,7 @@ class InsertGenerator(GenericGenerator):
 		# file, after escaping any triple-double quotes."""
 		if self.static:
 			data = open(self.page).read()
-			data= data.replace('"""', r'\"""')
+			data = data.replace('"""', r'\"""')
 			writer.println('res.write("""'+data+'""")')
 			writer.println()
 		else:
