@@ -65,8 +65,18 @@ class HTTPRequest(Request):
 			f.close()
 
 		# Get adapter, servlet path and query string
-		self._servletPath = env.get('SCRIPT_NAME', '')
-		self._pathInfo = env.get('PATH_INFO', '')
+		self._absolutepath = env.has_key('WK_ABSOLUTE') # set by adapter
+		if self._absolutepath:
+			# this is set when the servlet is a webserver file that shall
+			# be handled without context (e.g. when the psp-handler is used)
+			self._servletPath = '' # make it look like the normal handler
+			self._extraURLPath = env.get('PATH_INFO', '')
+			self._pathInfo = env.get('SCRIPT_NAME', '') + self._extraURLPath
+			self._fsPath = self.fsPath()
+		else:
+			self._servletPath = env.get('SCRIPT_NAME', '')
+			self._pathInfo = env.get('PATH_INFO', '')
+			self._extraURLPath = '' # will be determined later
 		self._queryString = env.get('QUERY_STRING', '')
 		if env.has_key('REQUEST_URI'):
 			self._uri = env['REQUEST_URI']
@@ -87,9 +97,6 @@ class HTTPRequest(Request):
 				self._uri = self._servletPath + self._pathInfo
 			if self._queryString:
 				self._uri += '?' + self._queryString
-		self._absolutepath = env.has_key('WK_ABSOLUTE') # set by adapter
-		if self._absolutepath:
-			self._fsPath = self.fsPath()
 
 		# We use the cgi module to get the fields,
 		# but then change them into an ordinary dictionary of values:
@@ -127,7 +134,7 @@ class HTTPRequest(Request):
 
 		self._contextName = None
 		self._serverSidePath = self._serverSideContextPath = None
-		self._serverRootPath = self._extraURLPath = ''
+		self._serverRootPath = ''
 		self._sessionExpired = False
 
 		self._pathInfo = self.pathInfo()
@@ -164,9 +171,16 @@ class HTTPRequest(Request):
 			return self.cookie(name, default)
 
 	def hasValue(self, name):
+		"""Check whether there is a value with the given name."""
 		return self._fields.has_key(name) or self._cookies.has_key(name)
 
 	def extraURLPath(self):
+		"""Return additional path components in the URL.
+
+		Only works if the Application.config setting "ExtraPathInfo"
+		is set to true; otherwise you will get a page not found error.
+
+		"""
 		return self._extraURLPath
 
 
@@ -402,7 +416,7 @@ class HTTPRequest(Request):
 		"""The filesystem path of the request according to the webserver."""
 		fspath = self.adapterFileName()
 		if not fspath:
-			fspath = self.servletPath()
+			fspath = self.adapterName()
 			docroot = self._environ['DOCUMENT_ROOT']
 			fspath = os.path.join(docroot, fspath)
 		return fspath
@@ -412,7 +426,7 @@ class HTTPRequest(Request):
 		return self.isSecure() and 'https' or 'http'
 
 	def hostAndPort(self):
-		"""Return hostname and port of this request."""
+		"""Return the hostname and port part from the URL of this request."""
 		env = self._environ
 		if env.has_key('HTTP_HOST'):
 			return env['HTTP_HOST']
