@@ -34,10 +34,6 @@ try:
 	PyThreadState_SetAsyncExc = pythonapi.PyThreadState_SetAsyncExc
 except (TypeError, AttributeError):
 	PyThreadState_SetAsyncExc = None
-try: # for Python < 2.5
-	BaseException
-except NameError:
-	BaseException = Exception
 
 from Common import *
 import AppServer as AppServerModule
@@ -863,18 +859,17 @@ class Handler:
 			block = self._sock.recv(missing)
 			if not block:
 				self._sock.close()
-				if len(chunk) == 0:
+				if not chunk:
 					# We probably awakened due to awakeSelect being called.
 					return None
-				else:
-					# We got a partial request -- something went wrong.
-					raise NotEnoughDataError, 'received only %d of %d bytes' \
-						' when receiving dictLength' % (len(chunk), intLength)
+				# We got a partial request -- something went wrong.
+				raise NotEnoughDataError, 'received only %d of %d bytes' \
+					' when receiving dictLength' % (len(chunk), intLength)
 			chunk += block
-			missing = intLength - len(chunk)
+			missing -= len(block)
 		try:
 			dictLength = loads(chunk)
-		except ValueError, msg:
+		except (ValueError, EOFError), msg:
 			if chunk[:3] == 'GET':
 				# Common error: client is speaking HTTP.
 				while msg and len(chunk) < 8192:
@@ -912,7 +907,7 @@ See the Troubleshooting section of the WebKit Install Guide.\r''')
 				raise NotEnoughDataError, 'received only %d of %d bytes' \
 					' when receiving dict' % (len(chunk), dictLength)
 			chunk += block
-			missing -= len(chunk)
+			missing -= len(block)
 		return loads(chunk)
 
 	def handleRequest(self):
@@ -1175,7 +1170,7 @@ See the Troubleshooting section of the WebKit Install Guide.\r''')
 				raise NotEnoughDataError, 'received only %d of %d bytes' \
 					' when receiving netstring' % (len(chunk), dictLength)
 			chunk += block
-			missing -= len(chunk)
+			missing -= len(block)
 		if self._sock.recv(1) != ',':
 			self._sock.close()
 			raise ProtocolError, 'Missing SCGI netstring terminator'
